How to Participate
==================

You can browse the code at `our github repo <https://github.com/stackforge/savanna>`_.

If you would like to ask some questions or make proposals,
feel free to reach us on #savanna irc channel at `freenode <http://freenode.net/>`_.
Typically somebody from our team will be online at irc from 6:00 to 20:00 UTC.
You can also contact Savanna community directly by mailto:savanna-all@lists.launchpad.net
(please, note that your email address should be registered in launchpad,
otherwise your mail will be ignored by mailing system).

We're going to hold public weekly meetings on Thursday at 18:00 UTC on #openstack-meeting-alt irc channel.

If you want to contribute either to docs or to code, simply send us change request via review.openstack.org (gerrit).
You can file `bugs <https://bugs.launchpad.net/savanna>`_ and register `blueprints <https://blueprints.launchpad.net/savanna>`_ at 
`Savanna launchpad page <https://launchpad.net/savanna>`_.